#ifndef NT2_INCLUDE_FUNCTIONS_POLYDER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POLYDER_HPP_INCLUDED

#include <nt2/polynom/include/functions/polyder.hpp>

#endif
